@@ -5,7 +5,7 @@ package Mojolicious::Plugin::BootstrapHelpers;
 
 # ABSTRACT: Type less bootstrap
 our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
-our $VERSION = '0.0201';
+our $VERSION = '0.0202';
 
 use Mojo::Base 'Mojolicious::Plugin';
 use Mojolicious::Plugin::BootstrapHelpers::Helpers;
@@ -84,8 +84,8 @@ Mojolicious::Plugin::BootstrapHelpers - Type less bootstrap
 <p>
 <img src="https://img.shields.io/badge/perl-5.20+-blue.svg" alt="Requires Perl 5.20+" />
 <a href="https://travis-ci.org/Csson/p5-mojolicious-plugin-bootstraphelpers"><img src="https://api.travis-ci.org/Csson/p5-mojolicious-plugin-bootstraphelpers.svg?branch=master" alt="Travis status" /></a>
-<a href="http://cpants.cpanauthors.org/dist/Mojolicious-Plugin-BootstrapHelpers-0.0201"><img src="https://badgedepot.code301.com/badge/kwalitee/Mojolicious-Plugin-BootstrapHelpers/0.0201" alt="Distribution kwalitee" /></a>
-<a href="http://matrix.cpantesters.org/?dist=Mojolicious-Plugin-BootstrapHelpers%200.0201"><img src="https://badgedepot.code301.com/badge/cpantesters/Mojolicious-Plugin-BootstrapHelpers/0.0201" alt="CPAN Testers result" /></a>
+<a href="http://cpants.cpanauthors.org/release/CSSON/Mojolicious-Plugin-BootstrapHelpers-0.0202"><img src="http://badgedepot.code301.com/badge/kwalitee/CSSON/Mojolicious-Plugin-BootstrapHelpers/0.0202" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=Mojolicious-Plugin-BootstrapHelpers%200.0202"><img src="http://badgedepot.code301.com/badge/cpantesters/Mojolicious-Plugin-BootstrapHelpers/0.0202" alt="CPAN Testers result" /></a>
 <img src="https://img.shields.io/badge/coverage-87.2%-orange.svg" alt="coverage 87.2%" />
 </p>
 
@@ -93,7 +93,7 @@ Mojolicious::Plugin::BootstrapHelpers - Type less bootstrap
 
 =head1 VERSION
 
-Version 0.0201, released 2016-03-23.
+Version 0.0202, released 2016-08-16.
 
 =head1 SYNOPSIS
 
